@@ -5,7 +5,8 @@
 #include <sigc++/limit_reference.h>
 #include <sigc++/tuple-utils/tuple_for_each.h>
 
-namespace sigc {
+namespace sigc
+{
 
 /** @defgroup track_obj track_obj()
  * sigc::track_obj() tracks trackable objects, referenced from a functor.
@@ -59,38 +60,36 @@ public:
    * @param _A_obj Trackable objects.
    */
   track_obj_functor(const T_functor& _A_func, const T_obj&... _A_obj)
-  : adapts<T_functor>(_A_func), obj_(_A_obj...) {}
+  : adapts<T_functor>(_A_func), obj_(_A_obj...)
+  {
+  }
 
   /** Invokes the wrapped functor.
    * @return The return value of the functor invocation.
    */
-  decltype(auto) operator()()
-  { return this->functor_(); }
-
+  decltype(auto) operator()() { return this->functor_(); }
 
   /** Invokes the wrapped functor passing on the arguments.
    * @param _A_arg... Arguments to be passed on to the functor.
    * @return The return value of the functor invocation.
    */
   template <typename... T_arg>
-  decltype(auto)
-  operator()(T_arg&&... _A_arg)
+  decltype(auto) operator()(T_arg&&... _A_arg)
   {
-    return this->functor_.template operator()<type_trait_pass_t<T_arg>...>
-      (std::forward<T_arg>(_A_arg)...);
+    return this->functor_.template operator()<type_trait_pass_t<T_arg>...>(
+      std::forward<T_arg>(_A_arg)...);
   }
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-//protected:
+  // protected:
   // public, so that visit_each() can access it.
   std::tuple<limit_reference<const T_obj>...> obj_;
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 }; // end class track_obj_functor
 
-
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-//template specialization of visitor<>::do_visit_each<>(action, functor):
+// template specialization of visitor<>::do_visit_each<>(action, functor):
 /** Performs a functor on each of the targets of a functor.
  * The function overload for sigc::track_obj_functor performs a functor
  * on the functor and on the trackable object instances stored in the
@@ -104,32 +103,29 @@ template <typename T_functor, typename... T_obj>
 struct visitor<track_obj_functor<T_functor, T_obj...>>
 {
   template <typename T_action>
-  static void do_visit_each(const T_action& _A_action,
-                            const track_obj_functor<T_functor, T_obj...>& _A_target)
+  static void do_visit_each(
+    const T_action& _A_action, const track_obj_functor<T_functor, T_obj...>& _A_target)
   {
     sigc::visit_each(_A_action, _A_target.functor_);
 
-    //Call sigc::visit_each(_A_action, element) on each element in the 
+    // Call sigc::visit_each(_A_action, element) on each element in the
     //_A_target.obj_ tuple:
     sigc::internal::tuple_for_each<TrackObjVisitForEach>(_A_target.obj_, _A_action);
   }
 
 private:
-  template<typename T_element>
+  template <typename T_element>
   struct TrackObjVisitForEach
   {
-    template<typename T_action>
-    static
-    void
-    visit(const T_element& element, const T_action& action)
+    template <typename T_action>
+    static void visit(const T_element& element, T_action&& action)
     {
-       sigc::visit_each(action, element);
+      sigc::visit_each(std::forward<T_action>(action), element);
     }
   };
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
-
 /** Creates an adaptor of type sigc::track_obj_functor which wraps a functor.
  * @param _A_func Functor that shall be wrapped.
  * @param _A_obj Trackable objects.
@@ -143,11 +139,9 @@ template <typename T_functor, typename... T_obj>
 inline decltype(auto)
 track_obj(const T_functor& _A_func, const T_obj&... _A_obj)
 {
-  return track_obj_functor<T_functor, T_obj...>
-    (_A_func, _A_obj...);
+  return track_obj_functor<T_functor, T_obj...>(_A_func, _A_obj...);
 }
 
-
 } /* namespace sigc */
 
 #endif /* _SIGC_ADAPTORS_TRACK_OBJ_H_ */
