@@ -6,9 +6,11 @@
 #include <sigc++/adaptors/adaptor_trait.h>
 #include <sigc++/functors/slot_base.h>
 
-namespace sigc {
+namespace sigc
+{
 
-namespace internal {
+namespace internal
+{
 
 /** A typed slot_rep.
  * A typed slot_rep holds a functor that can be invoked from
@@ -36,12 +38,16 @@ public:
    * @param functor The functor contained by the new slot_rep object.
    */
   inline typed_slot_rep(const T_functor& functor)
-    : slot_rep(nullptr, &destroy, &dup), functor_(functor)
-    { sigc::visit_each_type<trackable*>(slot_do_bind(this), functor_); }
+  : slot_rep(nullptr, &destroy, &dup), functor_(functor)
+  {
+    sigc::visit_each_type<trackable*>(slot_do_bind(this), functor_);
+  }
 
   inline typed_slot_rep(const typed_slot_rep& cl)
-    : slot_rep(cl.call_, &destroy, &dup), functor_(cl.functor_)
-    { sigc::visit_each_type<trackable*>(slot_do_bind(this), functor_); }
+  : slot_rep(cl.call_, &destroy, &dup), functor_(cl.functor_)
+  {
+    sigc::visit_each_type<trackable*>(slot_do_bind(this), functor_);
+  }
 
   typed_slot_rep& operator=(const typed_slot_rep& src) = delete;
 
@@ -49,41 +55,37 @@ public:
   typed_slot_rep& operator=(typed_slot_rep&& src) = delete;
 
   inline ~typed_slot_rep()
-    {
-      call_ = nullptr;
-      destroy_ = nullptr;
-      sigc::visit_each_type<trackable*>(slot_do_unbind(this), functor_);
-    }
+  {
+    call_ = nullptr;
+    destroy_ = nullptr;
+    sigc::visit_each_type<trackable*>(slot_do_unbind(this), functor_);
+  }
 
 private:
   /** Detaches the stored functor from the other referred trackables and destroys it.
    * This does not destroy the base slot_rep object.
    */
   static void destroy(notifiable* data)
-    {
-      self* self_ = static_cast<self*>(reinterpret_cast<slot_rep*>(data));
-      self_->call_ = nullptr;
-      self_->destroy_ = nullptr;
-      sigc::visit_each_type<trackable*>(slot_do_unbind(self_), self_->functor_);
-      self_->functor_.~adaptor_type();
-      /* don't call disconnect() here: destroy() is either called
-       * a) from the parent itself (in which case disconnect() leads to a segfault) or
-       * b) from a parentless slot (in which case disconnect() does nothing)
-       */
-    }
+  {
+    self* self_ = static_cast<self*>(reinterpret_cast<slot_rep*>(data));
+    self_->call_ = nullptr;
+    self_->destroy_ = nullptr;
+    sigc::visit_each_type<trackable*>(slot_do_unbind(self_), self_->functor_);
+    self_->functor_.~adaptor_type();
+    /* don't call disconnect() here: destroy() is either called
+     * a) from the parent itself (in which case disconnect() leads to a segfault) or
+     * b) from a parentless slot (in which case disconnect() does nothing)
+     */
+  }
 
   /** Makes a deep copy of the slot_rep object.
    * Deep copy means that the notification callback of the new
    * slot_rep object is registered in the referred trackables.
    * @return A deep copy of the slot_rep object.
    */
-  static slot_rep* dup(slot_rep* a_rep)
-    {
-      return new self(*static_cast<self*>(a_rep));
-    }
+  static slot_rep* dup(slot_rep* a_rep) { return new self(*static_cast<self*>(a_rep)); }
 };
 
-
 /** Abstracts functor execution.
  * call_it() invokes a functor of type @e T_functor with a list of
  * parameters whose types are given by the template arguments.
@@ -95,7 +97,7 @@ private:
  * - @e T_arg Argument types used in the definition of call_it().
  *
  */
-template<class T_functor, class T_return, class... T_arg>
+template <class T_functor, class T_return, class... T_arg>
 struct slot_call
 {
   /** Invokes a functor of type @p T_functor.
@@ -104,24 +106,20 @@ struct slot_call
    * @return The return values of the functor invocation.
    */
   static T_return call_it(slot_rep* rep, type_trait_take_t<T_arg>... a_)
-    {
-      using typed_slot = typed_slot_rep<T_functor>;
-      typed_slot *typed_rep = static_cast<typed_slot*>(rep);
-      return (typed_rep->functor_).template operator()<type_trait_take_t<T_arg>...>
-               (a_...);
-    }
+  {
+    using typed_slot = typed_slot_rep<T_functor>;
+    typed_slot* typed_rep = static_cast<typed_slot*>(rep);
+    return (typed_rep->functor_).template operator()<type_trait_take_t<T_arg>...>(a_...);
+  }
 
   /** Forms a function pointer from call_it().
    * @return A function pointer formed from call_it().
    */
-  static hook address()
-    { return reinterpret_cast<hook>(&call_it); }
+  static hook address() { return reinterpret_cast<hook>(&call_it); }
 };
 
-
 } /* namespace internal */
 
-
 // Because slot is opaque, visit_each() will not visit its internal members.
 // Those members are not reachable by visit_each() after the slot has been
 // constructed. But when a slot contains another slot, the outer slot will become
@@ -155,16 +153,16 @@ template <class T_return, class... T_arg>
 class slot;
 
 template <class T_return, class... T_arg>
-class slot<T_return(T_arg...)>
-  : public slot_base
+class slot<T_return(T_arg...)> : public slot_base
 {
 public:
   using result_type = T_return;
-  //TODO: using arg_type_ = type_trait_take_t<T_arg>;
+// TODO: using arg_type_ = type_trait_take_t<T_arg>;
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 private:
   using rep_type = internal::slot_rep;
+
 public:
   using call_type = T_return (*)(rep_type*, type_trait_take_t<T_arg>...);
 #endif
@@ -174,49 +172,41 @@ public:
    * @return The return value of the functor invocation.
    */
   inline T_return operator()(type_trait_take_t<T_arg>... _A_a) const
-    {
-      if (!empty() && !blocked())
-        return (reinterpret_cast<call_type>(slot_base::rep_->call_))(slot_base::rep_, _A_a...);
-      return T_return();
-    }
+  {
+    if (!empty() && !blocked())
+      return (reinterpret_cast<call_type>(slot_base::rep_->call_))(slot_base::rep_, _A_a...);
+    return T_return();
+  }
 
-  inline slot() {}
+  inline slot() = default;
 
   /** Constructs a slot from an arbitrary functor.
    * @param _A_func The desired functor the new slot should be assigned to.
    */
   template <class T_functor>
-  slot(const T_functor& _A_func)
-    : slot_base(new internal::typed_slot_rep<T_functor>(_A_func))
-    {
-      //The slot_base:: is necessary to stop the HP-UX aCC compiler from being confused. murrayc.
-      slot_base::rep_->call_ = internal::slot_call<T_functor, T_return, T_arg...>::address();
-    }
+  slot(const T_functor& _A_func) : slot_base(new internal::typed_slot_rep<T_functor>(_A_func))
+  {
+    // The slot_base:: is necessary to stop the HP-UX aCC compiler from being confused. murrayc.
+    slot_base::rep_->call_ = internal::slot_call<T_functor, T_return, T_arg...>::address();
+  }
 
   /** Constructs a slot, copying an existing one.
    * @param src The existing slot to copy.
    */
-  slot(const slot& src)
-    : slot_base(src)
-    {}
+  slot(const slot& src) = default;
 
   /** Constructs a slot, moving an existing one.
    * If @p src is connected to a parent (e.g. a signal), it is copied, not moved.
    * @param src The existing slot to move or copy.
    */
-  slot(slot&& src)
-    : slot_base(std::move(src))
-    {}
+  slot(slot&& src) : slot_base(std::move(src)) {}
 
   /** Overrides this slot, making a copy from another slot.
    * @param src The slot from which to make a copy.
    * @return @p this.
    */
   slot& operator=(const slot& src)
-  {
-    slot_base::operator=(src);
-    return *this;
-  }
+  = default;
 
   /** Overrides this slot, making a move from another slot.
    * If @p src is connected to a parent (e.g. a signal), it is copied, not moved.
@@ -231,7 +221,7 @@ public:
 };
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-//template specialization of visitor<>::do_visit_each<>(action, functor):
+// template specialization of visitor<>::do_visit_each<>(action, functor):
 /** Performs a functor on each of the targets of a functor.
  *
  * There are three function overloads for sigc::slot.
@@ -256,23 +246,24 @@ public:
 template <typename T_return, typename... T_arg>
 struct visitor<slot<T_return, T_arg...>>
 {
-  static void do_visit_each(const internal::limit_derived_target<trackable*, internal::slot_do_bind>& _A_action,
-                            const slot<T_return, T_arg...>& _A_target)
+  static void do_visit_each(
+    const internal::limit_derived_target<trackable*, internal::slot_do_bind>& _A_action,
+    const slot<T_return, T_arg...>& _A_target)
   {
     if (_A_target.rep_ && _A_target.rep_->parent_ == nullptr)
-    _A_target.rep_->set_parent(_A_action.action_.rep_, &internal::slot_rep::notify);
+      _A_target.rep_->set_parent(_A_action.action_.rep_, &internal::slot_rep::notify);
   }
 
-  static void do_visit_each(const internal::limit_derived_target<trackable*, internal::slot_do_unbind>& _A_action,
-                            const slot<T_return, T_arg...>& _A_target)
+  static void do_visit_each(
+    const internal::limit_derived_target<trackable*, internal::slot_do_unbind>& _A_action,
+    const slot<T_return, T_arg...>& _A_target)
   {
     if (_A_target.rep_ && _A_target.rep_->parent_ == _A_action.action_.rep_)
       _A_target.rep_->set_parent(nullptr, nullptr);
   }
 
   template <typename T_action>
-  static void do_visit_each(const T_action& _A_action,
-                            const slot<T_return, T_arg...>& _A_target)
+  static void do_visit_each(const T_action& _A_action, const slot<T_return, T_arg...>& _A_target)
   {
     _A_action(_A_target);
   }
