@@ -26,7 +26,8 @@
 namespace sigc
 {
 
-namespace internal {
+namespace internal
+{
 
 using hook = void* (*)(void*);
 
@@ -63,43 +64,23 @@ struct SIGC_API slot_rep : public trackable
   /* NB: Instead of slot_rep we could inherit slot_base from trackable.
    * However, a simple benchmark seems to indicate that this slows
    * down dereferencing of slot list iterators. Martin. */
-  //TODO: Try this now? murrayc.
-
-  /// Callback that invokes the contained functor.
-  /* This can't be a virtual function since number of arguments
-   * must be flexible. We use function pointers to slot_call::call_it()
-   * instead. call_ is set to zero to indicate that the slot is invalid.
-   */
-  hook call_;
-
-  /// Callback that detaches the slot_rep object from referred trackables and destroys it.
-  /* This could be a replaced by a virtual dtor. However since this struct is
-   * crucual for the efficiency of the whole library we want to avoid this.
-   */
-  func_destroy_notify destroy_;
-
-  using hook_dup = slot_rep* (*)(slot_rep*);
-
-private:
-  /** Callback that makes a deep copy of the slot_rep object.
-   * @return A deep copy of the slot_rep object.
-   */
-  hook_dup dup_;
+  // TODO: Try this now? murrayc.
 
 public:
-  /** Callback of parent_. */
-  func_destroy_notify cleanup_;
-
-  /** Parent object whose callback cleanup_ is executed on notification. */
-  notifiable* parent_;
+  using hook_dup = slot_rep* (*)(slot_rep*);
 
   inline slot_rep(hook call__, notifiable::func_destroy_notify destroy__, hook_dup dup__) noexcept
-    : call_(call__), destroy_(destroy__), dup_(dup__), cleanup_(nullptr), parent_(nullptr) {}
+    : call_(call__),
+      cleanup_(nullptr),
+      parent_(nullptr),
+      destroy_(destroy__),
+      dup_(dup__)
+  {
+  }
 
-  inline ~slot_rep()
-    { destroy(); }
+  inline ~slot_rep() { destroy(); }
 
-  // only MSVC needs this to guarantee that all new/delete are executed from the DLL module
+// only MSVC needs this to guarantee that all new/delete are executed from the DLL module
 #ifdef SIGC_NEW_DELETE_IN_LIBRARY_ONLY
   void* operator new(size_t size_);
   void operator delete(void* p);
@@ -108,13 +89,18 @@ public:
   /** Destroys the slot_rep object (but doesn't delete it).
    */
   inline void destroy()
-    { if (destroy_) (*destroy_)(this); }
+  {
+    if (destroy_)
+      (*destroy_)(this);
+  }
 
   /** Makes a deep copy of the slot_rep object.
    * @return A deep copy of the slot_rep object.
    */
   inline slot_rep* dup() const
-    { return reinterpret_cast<slot_rep*>((*dup_)(const_cast<slot_rep*>(this))); }
+  {
+    return reinterpret_cast<slot_rep*>((*dup_)(const_cast<slot_rep*>(this)));
+  }
 
   /** Set the parent with a callback.
    * slots have one parent exclusively.
@@ -122,10 +108,10 @@ public:
    * @param cleanup The callback to execute from notify().
    */
   inline void set_parent(notifiable* parent, notifiable::func_destroy_notify cleanup) noexcept
-    {
-      parent_ = parent;
-      cleanup_ = cleanup;
-    }
+  {
+    parent_ = parent;
+    cleanup_ = cleanup;
+  }
 
   /// Invalidates the slot and executes the parent's cleanup callback.
   void disconnect();
@@ -138,6 +124,32 @@ public:
    * @param data The slot_rep object that is becoming invalid (@p this).
    */
   static void notify(notifiable* data);
+
+  /// Callback that invokes the contained functor.
+  /* This can't be a virtual function since number of arguments
+   * must be flexible. We use function pointers to slot_call::call_it()
+   * instead. call_ is set to zero to indicate that the slot is invalid.
+   */
+  hook call_;
+
+  /** Callback of parent_. */
+  func_destroy_notify cleanup_;
+
+  /** Parent object whose callback cleanup_ is executed on notification. */
+  notifiable* parent_;
+
+protected:
+  /// Callback that detaches the slot_rep object from referred trackables and destroys it.
+  /* This could be a replaced by a virtual dtor. However since this struct is
+   * crucual for the efficiency of the whole library we want to avoid this.
+   */
+  func_destroy_notify destroy_;
+
+private:
+  /** Callback that makes a deep copy of the slot_rep object.
+   * @return A deep copy of the slot_rep object.
+   */
+  hook_dup dup_;
 };
 
 /** Functor used to add a dependency to a trackable.
@@ -152,13 +164,15 @@ struct SIGC_API slot_do_bind
   /** Construct a slot_do_bind functor.
    * @param rep The slot_rep object trackables should notify on destruction.
    */
-  inline slot_do_bind(slot_rep* rep) noexcept : rep_(rep) {}
+  inline explicit slot_do_bind(slot_rep* rep) noexcept : rep_(rep) {}
 
   /** Adds a dependency to @p t.
    * @param t The trackable object to add a callback to.
    */
   inline void operator()(const trackable* t) const
-    { t->add_destroy_notify_callback(rep_, &slot_rep::notify); }
+  {
+    t->add_destroy_notify_callback(rep_, &slot_rep::notify);
+  }
 };
 
 /// Functor used to remove a dependency from a trackable.
@@ -170,24 +184,24 @@ struct SIGC_API slot_do_unbind
   /** Construct a slot_do_unbind functor.
    * @param rep The slot_rep object trackables don't need to notify on destruction any more.
    */
-  inline slot_do_unbind(slot_rep* rep) noexcept : rep_(rep) {}
+  inline explicit slot_do_unbind(slot_rep* rep) noexcept : rep_(rep) {}
 
   /** Removes a dependency from @p t.
    * @param t The trackable object to remove the callback from.
    */
-  inline void operator()(const trackable* t) const
-    { t->remove_destroy_notify_callback(rep_); }
+  inline void operator()(const trackable* t) const { t->remove_destroy_notify_callback(rep_); }
 };
 
-} //namespace internal
-
+} // namespace internal
 
 /** @defgroup slot Slots
  * Slots are type-safe representations of callback methods and functions.
  * A slot can be constructed from any function object or function, regardless of
  * whether it is a global function, a member method, static, or virtual.
  *
- * Use the sigc::mem_fun() and sigc::ptr_fun() template functions to get a sigc::slot, like so:
+ * @section slots-creating Creating Slots
+ *
+ * Use the sigc::mem_fun() or sigc::ptr_fun() template functions to get a sigc::slot, like so:
  * @code
  * sigc::slot<void(int)> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
  * @endcode
@@ -204,6 +218,13 @@ struct SIGC_API slot_do_unbind
  *
  * You can also pass slots as method parameters where you might normally pass a function pointer.
  *
+ * @section slots-auto-disconnect Member Methods and Automatic Disconnection
+ *
+ * See @ref mem_fun "sigc::mem_fun()" about deriving from sigc::trackable to prevent member
+ * methods from being called after the instance has been destroyed.
+ *
+ * @section slots-auto auto
+ *
  * sigc::mem_fun() and sigc::ptr_fun() return functors, but those functors are
  * not slots.
  * @code
@@ -214,6 +235,12 @@ struct SIGC_API slot_do_unbind
  * auto sl = sigc::mem_fun(someobj, &SomeClass::somemethod); // Not a slot!
  * @endcode
  *
+ * If you don't explicitly use a sigc::slot then the slot could call a method
+ * on an instance after it has been destroyed even if the method is in a class
+ * that derives from sigc::trackable.
+ *
+ * @section slots-with-lambdas C++ Lambdas
+ *
  * A C++11 lambda expression is a functor (function object). It is automatically
  * wrapped in a slot, if it is connected to a signal.
  * @code
@@ -226,11 +253,9 @@ struct SIGC_API slot_do_unbind
  * @endcode
  *
  * If you connect a C++11 lambda expression or a std::function<> instance to
- * a signal or assign it to a slot,
- * - With libsigc++ versions before 2.6, if the return type is not void,
-     you must use the #SIGC_FUNCTORS_DEDUCE_RESULT_TYPE_WITH_DECLTYPE macro,
- * - if your functor contains references to sigc::trackable derived objects,
- *   those objects will not be tracked, unless you also use sigc::track_obj().
+ * a signal or assign it to a slot, if your functor contains references to
+ * sigc::trackable derived objects, those objects will not be tracked,
+ * unless you also use sigc::track_obj().
  *
  * @ingroup sigcfunctors
  */
@@ -300,8 +325,6 @@ public:
    */
   void set_parent(notifiable* parent, notifiable::func_destroy_notify cleanup) const noexcept;
 
-
-
   /** Add a callback that is executed (notified) when the slot is detroyed.
    * This function is used internally by connection objects.
    * @param data Passed into func upon notification.
@@ -318,15 +341,13 @@ public:
   /** Returns whether the slot is invalid.
    * @return @p true if the slot is invalid (empty).
    */
-  inline bool empty() const noexcept
-    { return (!rep_ || !rep_->call_); }
+  inline bool empty() const noexcept { return (!rep_ || !rep_->call_); }
 
   /** Returns whether the slot is blocked.
    * @return @p true if the slot is blocked.
    */
-  inline bool blocked() const noexcept
-    { return blocked_; }
-    
+  inline bool blocked() const noexcept { return blocked_; }
+
   /** Sets the blocking state.
    * If @e should_block is @p true then the blocking state is set.
    * Subsequent calls to slot::operator()() don't invoke the functor
@@ -347,9 +368,10 @@ public:
    */
   void disconnect();
 
-//The Tru64 and Solaris Forte 5.5 compilers needs this operator=() to be public. I'm not sure why, or why it needs to be protected usually. murrayc.
-//See bug #168265. 
-//protected:
+  // The Tru64 and Solaris Forte 5.5 compilers needs this operator=() to be public. I'm not sure
+  // why, or why it needs to be protected usually. murrayc.
+  // See bug #168265.
+  // protected:
   /** Overrides this slot, making a copy from another slot.
    * @param src The slot from which to make a copy.
    * @return @p this.
@@ -365,7 +387,7 @@ public:
 
 public: // public to avoid template friend declarations
   /** Typed slot_rep object that contains a functor. */
-  mutable rep_type *rep_;
+  mutable rep_type* rep_;
 
   /** Indicates whether the slot is blocked. */
   bool blocked_;
@@ -374,7 +396,6 @@ private:
   void delete_rep_with_check();
 };
 
-} //namespace sigc
+} // namespace sigc
 
 #endif //_SIGC_SLOT_BASE_HPP_
-
