@@ -21,8 +21,8 @@
 
 #include <sigc++config.h>
 
-
-namespace sigc {
+namespace sigc
+{
 
 template <class T_type>
 struct type_trait
@@ -52,17 +52,17 @@ struct type_trait<const T_type&>
   using take = const T_type&;
 };
 
-template<>
+template <>
 struct type_trait<void>
 {
   using pass = void;
   using take = void;
 };
 
-template<typename T>
+template <typename T>
 using type_trait_pass_t = typename type_trait<T>::pass;
 
-template<typename T>
+template <typename T>
 using type_trait_take_t = typename type_trait<T>::take;
 
 } /* namespace sigc */
