@@ -21,33 +21,42 @@
 #include <sigc++/type_traits.h>
 #include <type_traits>
 
-namespace sigc {
+namespace sigc
+{
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-namespace internal {
+namespace internal
+{
 
-//This should really be an inner class of limit_derived_target, without the T_limit template type,
-//But the SUN CC 5.7 (not earlier versions) compiler finds it ambiguous when we specify a particular specialization of it.
-//and does not seem to allow us to tell it explicitly that it's an inner class.
+template <class Base, class Derived>
+constexpr bool is_base_of_or_same_v =
+  std::is_base_of<std::decay_t<Base>, std::decay_t<Derived>>::value ||
+    std::is_same<std::decay_t<Base>, std::decay_t<Derived>>::value;
+
+// This should really be an inner class of limit_derived_target, without the T_limit template type,
+// But the SUN CC 5.7 (not earlier versions) compiler finds it ambiguous when we specify a
+// particular specialization of it.
+// and does not seem to allow us to tell it explicitly that it's an inner class.
 template <bool I_derived, class T_type, class T_limit>
 struct with_type;
 
-//Specialization for I_derived = false
-template <class T_type, class T_limit> struct
-with_type<false, T_type, T_limit>
+// Specialization for I_derived = false
+template <class T_type, class T_limit>
+struct with_type<false, T_type, T_limit>
 {
   static void execute_(const T_type&, const T_limit&) {}
 };
 
-//Specialization for I_derived = true
+// Specialization for I_derived = true
 template <class T_type, class T_limit>
 struct with_type<true, T_type, T_limit>
 {
   static void execute_(const T_type& _A_type, const T_limit& _A_action)
-  { _A_action.action_(_A_type); }
+  {
+    _A_action.action_(_A_type);
+  }
 };
 
-
 /// Helper struct for visit_each_type().
 template <class T_target, class T_action>
 struct limit_derived_target
@@ -55,36 +64,38 @@ struct limit_derived_target
   using T_self = limit_derived_target<T_target, T_action>;
 
   template <class T_type>
-  void operator()(const T_type& _A_type) const
+  void operator()(T_type&& _A_type) const
   {
-    with_type<std::is_base_of<T_target, T_type>::value || std::is_same<T_target, T_type>::value, T_type, T_self>::execute_(_A_type, *this);
+    with_type<is_base_of_or_same_v<T_target, T_type>,
+      T_type, T_self>::execute_(std::forward<T_type>(_A_type), *this);
   }
 
-  limit_derived_target(const T_action& _A_action)
-  : action_(_A_action)
-  {}
+  explicit limit_derived_target(const T_action& _A_action) : action_(_A_action) {}
 
   T_action action_;
 };
 
-// Specialization for T_target pointer types, to provide a slightly different execute_() implementation.
+// Specialization for T_target pointer types, to provide a slightly different execute_()
+// implementation.
 
 template <bool I_derived, class T_type, class T_limit>
 struct with_type_pointer;
 
-//Specialization for I_derived = false
+// Specialization for I_derived = false
 template <class T_type, class T_limit>
 struct with_type_pointer<false, T_type, T_limit>
 {
- static void execute_(const T_type&, const T_limit&) {}
+  static void execute_(const T_type&, const T_limit&) {}
 };
 
-//Specialization for I_derived = true
+// Specialization for I_derived = true
 template <class T_type, class T_limit>
 struct with_type_pointer<true, T_type, T_limit>
 {
   static void execute_(const T_type& _A_type, const T_limit& _A_action)
-  { _A_action.action_(&_A_type); }
+  {
+    _A_action.action_(&_A_type);
+  }
 };
 
 template <class T_target, class T_action>
@@ -93,14 +104,13 @@ struct limit_derived_target<T_target*, T_action>
   using T_self = limit_derived_target<T_target*, T_action>;
 
   template <class T_type>
-  void operator()(const T_type& _A_type) const
+  void operator()(T_type&& _A_type) const
   {
-    with_type_pointer<std::is_base_of<T_target, T_type>::value || std::is_same<T_target, T_type>::value, T_type, T_self>::execute_(_A_type, *this);
+    with_type_pointer<is_base_of_or_same_v<T_target, T_type>,
+      T_type, T_self>::execute_(std::forward<T_type>(_A_type), *this);
   }
 
-  limit_derived_target(const T_action& _A_action)
-  : action_(_A_action)
-  {}
+  explicit limit_derived_target(const T_action& _A_action) : action_(_A_action) {}
 
   T_action action_;
 };
@@ -115,7 +125,8 @@ struct limit_derived_target<T_target*, T_action>
 // (argument-dependent lookup), and therefore there is no risk that a visit_each() overload
 // in e.g. Boost is selected by mistake.
 
-/** sigc::visitor<T_functor>::do_visit_each() performs a functor on each of the targets of a functor.
+/** sigc::visitor<T_functor>::do_visit_each() performs a functor on each of the targets of a
+ * functor.
  * All unknown types just call @a _A_action on them.
  * Add specializations that specialize the @a T_functor argument for your own
  * functor types, so that subobjects get visited. This is needed to enable
@@ -166,8 +177,11 @@ struct visitor
  * @ingroup sigcfunctors
  */
 template <class T_action, class T_functor>
-void visit_each(const T_action& _A_action, const T_functor& _A_functor)
-{ sigc::visitor<T_functor>::do_visit_each(_A_action, _A_functor); }
+void
+visit_each(const T_action& _A_action, const T_functor& _A_functor)
+{
+  sigc::visitor<T_functor>::do_visit_each(_A_action, _A_functor);
+}
 
 /** This function performs a functor on each of the targets
  * of a functor limited to a restricted type.
@@ -175,29 +189,32 @@ void visit_each(const T_action& _A_action, const T_functor& _A_functor)
  * @ingroup sigcfunctors
  */
 template <class T_type, class T_action, class T_functor>
-void visit_each_type(const T_action& _A_action, const T_functor& _A_functor)
+void
+visit_each_type(const T_action& _A_action, const T_functor& _A_functor)
 {
   using type_limited_action = internal::limit_derived_target<T_type, T_action>;
 
   type_limited_action limited_action(_A_action);
 
-  //specifying the types of the template specialization prevents disconnection of bound trackable references (such as with std::ref()),
-  //probably because the visit_each<> specializations take various different template types,
-  //in various sequences, and we are probably specifying only a subset of them with this.
+  // specifying the types of the template specialization prevents disconnection of bound trackable
+  // references (such as with std::ref()),
+  // probably because the visit_each<> specializations take various different template types,
+  // in various sequences, and we are probably specifying only a subset of them with this.
   //
-  //But this is required by the AIX (and maybe IRIX MipsPro  and Tru64) compilers.
-  //I guess that std::ref() therefore does not work on those platforms. murrayc
+  // But this is required by the AIX (and maybe IRIX MipsPro  and Tru64) compilers.
+  // I guess that std::ref() therefore does not work on those platforms. murrayc
   // sigc::visit_each<type_limited_action, T_functor>(limited_action, _A_functor);
 
-  //g++ (even slightly old ones) is our primary platform, so we could use the non-crashing version.
-  //However, the explicit version also fixes a crash in a slightly more common case: http://bugzilla.gnome.org/show_bug.cgi?id=169225
-  //Users (and distributors) of libsigc++ on AIX (and maybe IRIX MipsPro and Tru64) do
-  //need to use the version above instead, to allow compilation.
+  // g++ (even slightly old ones) is our primary platform, so we could use the non-crashing version.
+  // However, the explicit version also fixes a crash in a slightly more common case:
+  // http://bugzilla.gnome.org/show_bug.cgi?id=169225
+  // Users (and distributors) of libsigc++ on AIX (and maybe IRIX MipsPro and Tru64) do
+  // need to use the version above instead, to allow compilation.
 
-  //Added 2014-03-20: The preceding comment probably does not apply any more,
-  //now when the visit_each<>() overloads have been replaced by visitor<> specializations.
-  //It's probably safe to add explicit template parameters on calls to visit_each(),
-  //visit_each_type() and visitor::do_visit_each(), if necessary.
+  // Added 2014-03-20: The preceding comment probably does not apply any more,
+  // now when the visit_each<>() overloads have been replaced by visitor<> specializations.
+  // It's probably safe to add explicit template parameters on calls to visit_each(),
+  // visit_each_type() and visitor::do_visit_each(), if necessary.
 
   sigc::visit_each(limited_action, _A_functor);
 }
