@@ -12,21 +12,23 @@
 #include <sstream>
 #include <cstdlib>
 
-//The Tru64 compiler seems to need this to avoid an unresolved symbol
-//See bug #161503
+// The Tru64 compiler seems to need this to avoid an unresolved symbol
+// See bug #161503
 #include <new>
 
 namespace
 {
 std::ostringstream result_stream;
 
-int foo(int i)
+int
+foo(int i)
 {
   result_stream << "foo(" << i << ") ";
   return 1;
 }
 
-int bar(double i)
+int
+bar(double i)
 {
   result_stream << "bar(" << i << ") ";
   return 1;
@@ -41,7 +43,8 @@ struct A : public sigc::trackable
   }
 };
 
-void good_bye_world()
+void
+good_bye_world()
 {
   result_stream << "Good bye world!";
 }
@@ -55,27 +58,22 @@ struct B : public sigc::trackable
     sig.connect(sigc::ptr_fun(&good_bye_world));
   }
 
-  void destroy()   // Calling destroy() during signal emission seems weird!
-  {                // However, if this works, anything will work!
-    delete this;   // valgrind reports a small memory leak, that's all.
+  void destroy() // Calling destroy() during signal emission seems weird!
+  { // However, if this works, anything will work!
+    delete this; // valgrind reports a small memory leak, that's all.
   }
 
-  void boom()
-  {
-    result_stream << "boom!";
-  }
+  void boom() { result_stream << "boom!"; }
 
-  void emit()
-  {
-    sig.emit();
-  }
+  void emit() { sig.emit(); }
 
   sigc::signal<void()> sig;
 };
 
 } // end anonymous namespace
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
   auto util = TestUtilities::get_instance();
 
@@ -85,7 +83,7 @@ int main(int argc, char* argv[])
   sigc::signal<int(int)> sig;
   sigc::signal<int(int)>::iterator confoo;
   sigc::signal<int(int)>::iterator conbar;
-  sigc::connection cona;  // connection objects are safe to use beyond the life time of a signal.
+  sigc::connection cona; // connection objects are safe to use beyond the life time of a signal.
 
   {
     A a;
@@ -94,20 +92,20 @@ int main(int argc, char* argv[])
     conbar = sig.connect(sigc::ptr_fun(&bar));
     result_stream << "sig is connected to A::foo, foo, bar (size=" << sig.size() << "): ";
     sig(1);
-    util->check_result(result_stream,
-      "sig is connected to A::foo, foo, bar (size=3): A::foo(1) foo(1) bar(1) ");
-  }                     // auto disconnection! iterators stay valid after disconnections.
+    util->check_result(
+      result_stream, "sig is connected to A::foo, foo, bar (size=3): A::foo(1) foo(1) bar(1) ");
+  } // auto disconnection! iterators stay valid after disconnections.
 
   result_stream << "sig is connected to foo, bar (size=" << sig.size() << "): ";
   sig(2);
   util->check_result(result_stream, "sig is connected to foo, bar (size=2): foo(2) bar(2) ");
 
-  A a;                  // iterators stay valid after further connections.
+  A a; // iterators stay valid after further connections.
   cona = sig.slots().insert(conbar, sigc::mem_fun(a, &A::foo));
   result_stream << "sig is connected to foo, A::foo, bar (size=" << sig.size() << "): ";
   sig(3);
-  util->check_result(result_stream,
-    "sig is connected to foo, A::foo, bar (size=3): foo(3) A::foo(3) bar(3) ");
+  util->check_result(
+    result_stream, "sig is connected to foo, A::foo, bar (size=3): foo(3) A::foo(3) bar(3) ");
 
   conbar->disconnect(); // manual disconnection
   result_stream << "sig is connected to foo, A::foo (size=" << sig.size() << "): ";
@@ -119,19 +117,21 @@ int main(int argc, char* argv[])
   sig(5);
   util->check_result(result_stream, "sig is connected to A::foo (size=1): A::foo(5) ");
 
-  cona.disconnect();    // manual disconnection
+  cona.disconnect(); // manual disconnection
   result_stream << "sig is empty (size=" << sig.size() << "): ";
   sig(6);
   util->check_result(result_stream, "sig is empty (size=0): ");
 
-  cona.disconnect();    // already disconnected -> legal with connection objects, however, nothing happens ...
+  cona.disconnect(); // already disconnected -> legal with connection objects, however, nothing
+                     // happens ...
 
   {
     A a2;
     sig.connect(sigc::compose(sigc::mem_fun(a2, &A::foo), &foo));
     result_stream << "sig is connected to compose(A::foo, foo) (size=" << sig.size() << "): ";
     sig(7);
-    util->check_result(result_stream, "sig is connected to compose(A::foo, foo) (size=1): foo(7) A::foo(1) ");
+    util->check_result(
+      result_stream, "sig is connected to compose(A::foo, foo) (size=1): foo(7) A::foo(1) ");
   }
   result_stream << "sig is empty (size=" << sig.size() << "): ";
   sig(8);
@@ -141,9 +141,11 @@ int main(int argc, char* argv[])
     A a2;
     sigc::slot<int(int)> setter = sigc::mem_fun(a2, &A::foo);
     sig.connect(sigc::compose(setter, &foo));
-    result_stream << "sig is connected to compose(slot1(A::foo), foo) (size=" << sig.size() << "): ";
+    result_stream << "sig is connected to compose(slot1(A::foo), foo) (size=" << sig.size()
+                  << "): ";
     sig(9);
-    util->check_result(result_stream, "sig is connected to compose(slot1(A::foo), foo) (size=1): foo(9) A::foo(1) ");
+    util->check_result(
+      result_stream, "sig is connected to compose(slot1(A::foo), foo) (size=1): foo(9) A::foo(1) ");
   }
   result_stream << "sig is empty (size=" << sig.size() << "): ";
   sig(10);
@@ -155,7 +157,8 @@ int main(int argc, char* argv[])
     sig.connect(sigc::compose(setter, &foo));
     result_stream << "sig is connected to compose(slot(A::foo), foo) (size=" << sig.size() << "): ";
     sig(11);
-    util->check_result(result_stream, "sig is connected to compose(slot(A::foo), foo) (size=1): foo(11) A::foo(1) ");
+    util->check_result(
+      result_stream, "sig is connected to compose(slot(A::foo), foo) (size=1): foo(11) A::foo(1) ");
   }
   result_stream << "sig is empty (size=" << sig.size() << "): ";
   sig(12);
